=== modified file 'breezy/bundle/serializer/v08.py'
--- breezy/bundle/serializer/v08.py	2018-06-18 00:19:26 +0000
+++ breezy/bundle/serializer/v08.py	2018-07-08 14:45:27 +0000
@@ -23,11 +23,15 @@
     errors,
     ui,
     )
-from breezy.bundle.serializer import (BundleSerializer,
-                                      _get_bundle_header,
-                                     )
+from breezy.bundle.serializer import (
+    BundleSerializer,
+    _get_bundle_header,
+    )
 from breezy.bundle.serializer import binary_diff
-from breezy.bundle.bundle_data import (RevisionInfo, BundleInfo)
+from breezy.bundle.bundle_data import (
+    RevisionInfo,
+    BundleInfo,
+    )
 from breezy.diff import internal_diff
 from breezy.revision import NULL_REVISION
 from breezy.sixish import text_type
@@ -69,17 +73,17 @@
 
     def write(self, to_file):
         """Write action as to a file"""
-        p_texts = [b' '.join([self.name]+self.parameters)]
+        p_texts = [' '.join([self.name]+self.parameters)]
         for prop in self.properties:
             if len(prop) == 1:
                 p_texts.append(prop[0])
             else:
                 try:
-                    p_texts.append(b'%s:%s' % prop)
+                    p_texts.append('%s:%s' % prop)
                 except:
                     raise repr(prop)
-        text = [b'=== ']
-        text.append(b' // '.join(p_texts))
+        text = ['=== ']
+        text.append(' // '.join(p_texts))
         text_line = ''.join(text).encode('utf-8')
         available = 79
         while len(text_line) > available:
@@ -91,6 +95,7 @@
 
 
 class BundleSerializerV08(BundleSerializer):
+
     def read(self, f):
         """Read the rest of the bundles from the supplied file.
 
@@ -236,7 +241,7 @@
                             trailing_space_when_empty=True)
 
         # Add an extra blank space at the end
-        self.to_file.write('\n')
+        self.to_file.write(b'\n')
 
     def _write_action(self, name, parameters, properties=None):
         if properties is None:
@@ -393,9 +398,9 @@
         for line in self._next():
             # The bzr header is terminated with a blank line
             # which does not start with '#'
-            if line is None or line == '\n':
+            if line is None or line == b'\n':
                 break
-            if not line.startswith('#'):
+            if not line.startswith(b'#'):
                 continue
             found_something = True
             self._handle_next(line)
@@ -407,7 +412,7 @@
     def _read_next_entry(self, line, indent=1):
         """Read in a key-value pair
         """
-        if not line.startswith('#'):
+        if not line.startswith(b'#'):
             raise errors.MalformedHeader('Bzr header did not start with #')
         line = line[1:-1].decode('utf-8') # Remove the '#' and '\n'
         if line[:indent] == ' '*indent:
@@ -462,14 +467,14 @@
         does not start properly indented.
         """
         values = []
-        start = '#' + (' '*indent)
+        start = b'#' + (b' '*indent)
 
-        if self._next_line is None or self._next_line[:len(start)] != start:
+        if self._next_line is None or not self._next_line.startswith(start):
             return values
 
         for line in self._next():
             values.append(line[len(start):-1].decode('utf-8'))
-            if self._next_line is None or self._next_line[:len(start)] != start:
+            if self._next_line is None or not self._next_line.startswith(start):
                 break
         return values
 
@@ -481,7 +486,7 @@
         """
         #mutter('_read_one_patch: %r' % self._next_line)
         # Peek and see if there are no patches
-        if self._next_line is None or self._next_line.startswith('#'):
+        if self._next_line is None or self._next_line.startswith(b'#'):
             return None, [], False
 
         first = True
@@ -530,7 +535,7 @@
             self._handle_next(line)
             if self._next_line is None:
                 break
-            if not self._next_line.startswith('#'):
+            if not self._next_line.startswith(b'#'):
                 # Consume the trailing \n and stop processing
                 next(self._next())
                 break

=== modified file 'breezy/merge.py'
--- breezy/merge.py	2018-06-22 01:36:02 +0000
+++ breezy/merge.py	2018-07-08 14:45:27 +0000
@@ -1686,10 +1686,10 @@
             plan = list(plan)
             trans_id = self.tt.trans_id_file_id(file_id)
             name = self.tt.final_name(trans_id) + '.plan'
-            contents = ('%11s|%s' % l for l in plan)
+            contents = (b'%11s|%s' % l for l in plan)
             self.tt.new_file(name, self.tt.final_parent(trans_id), contents)
-        textmerge = versionedfile.PlanWeaveMerge(plan, '<<<<<<< TREE\n',
-                                                 '>>>>>>> MERGE-SOURCE\n')
+        textmerge = versionedfile.PlanWeaveMerge(plan, b'<<<<<<< TREE\n',
+                                                 b'>>>>>>> MERGE-SOURCE\n')
         lines, conflicts = textmerge.merge_lines(self.reprocess)
         if conflicts:
             base_lines = textmerge.base_from_plan()

=== modified file 'breezy/merge3.py'
--- breezy/merge3.py	2018-06-17 11:15:04 +0000
+++ breezy/merge3.py	2018-07-08 14:45:27 +0000
@@ -26,6 +26,12 @@
     )
 
 
+class CantReprocessAndShowBase(errors.BzrError):
+
+    _fmt = ("Can't reprocess and show base, because reprocessing obscures "
+           "the relationship of conflicting lines to the base")
+
+
 def intersect(ra, rb):
     """Given two ranges return the range where they intersect or None.
 
@@ -60,8 +66,6 @@
         return True
 
 
-
-
 class Merge3(object):
     """3-way merge of texts.
 
@@ -109,7 +113,7 @@
             elif self.a[0].endswith(b'\r'):
                 newline = b'\r'
         if base_marker and reprocess:
-            raise errors.CantReprocessAndShowBase()
+            raise CantReprocessAndShowBase()
         if name_a:
             start_marker = start_marker + b' ' + name_a
         if name_b:

=== modified file 'breezy/merge_directive.py'
--- breezy/merge_directive.py	2018-06-30 22:25:16 +0000
+++ breezy/merge_directive.py	2018-07-08 14:45:27 +0000
@@ -16,6 +16,7 @@
 
 from __future__ import absolute_import
 
+import base64
 import re
 
 from . import lazy_import
@@ -143,9 +144,9 @@
                 stanza.add(key, self.__dict__[key])
         if base_revision:
             stanza.add('base_revision_id', self.base_revision_id)
-        lines = ['# ' + self._format_string + '\n']
+        lines = [b'# ' + self._format_string + b'\n']
         lines.extend(rio.to_patch_lines(stanza))
-        lines.append('# \n')
+        lines.append(b'# \n')
         return lines
 
     def write_to_directory(self, path):
@@ -369,7 +370,7 @@
     directly using the standard patch program.
     """
 
-    _format_string = 'Bazaar merge directive format 1'
+    _format_string = b'Bazaar merge directive format 1'
 
     def __init__(self, revision_id, testament_sha1, time, timezone,
                  target_branch, patch=None, patch_type=None,
@@ -424,7 +425,7 @@
         firstline = b""
         for line in line_iter:
             if line.startswith(b'# Bazaar merge directive format '):
-                return _format_registry.get(line[2:].rstrip().decode('utf-8', 'replace'))._from_lines(
+                return _format_registry.get(line[2:].rstrip())._from_lines(
                     line_iter)
             firstline = firstline or line.strip()
         raise errors.NotAMergeDirective(firstline)
@@ -480,7 +481,7 @@
 
 class MergeDirective2(BaseMergeDirective):
 
-    _format_string = 'Bazaar merge directive format 2 (Bazaar 0.90)'
+    _format_string = b'Bazaar merge directive format 2 (Bazaar 0.90)'
 
     def __init__(self, revision_id, testament_sha1, time, timezone,
                  target_branch, patch=None, source_branch=None, message=None,
@@ -510,7 +511,7 @@
         if self.bundle is None:
             return None
         else:
-            return self.bundle.decode('base-64')
+            return base64.b64decode(self.bundle)
 
     @classmethod
     def _from_lines(klass, line_iter):
@@ -554,10 +555,10 @@
     def to_lines(self):
         lines = self._to_lines(base_revision=True)
         if self.patch is not None:
-            lines.append('# Begin patch\n')
+            lines.append(b'# Begin patch\n')
             lines.extend(self.patch.splitlines(True))
         if self.bundle is not None:
-            lines.append('# Begin bundle\n')
+            lines.append(b'# Begin bundle\n')
             lines.extend(self.bundle.splitlines(True))
         return lines
 
@@ -620,8 +621,8 @@
                 patch = None
 
             if include_bundle:
-                bundle = klass._generate_bundle(repository, revision_id,
-                    ancestor_id).encode('base-64')
+                bundle = base64.b64encode(klass._generate_bundle(repository, revision_id,
+                    ancestor_id))
             else:
                 bundle = None
 
@@ -645,11 +646,11 @@
         calculated_patch = self._generate_diff(repository, self.revision_id,
                                                self.base_revision_id)
         # Convert line-endings to UNIX
-        stored_patch = re.sub('\r\n?', '\n', self.patch)
-        calculated_patch = re.sub('\r\n?', '\n', calculated_patch)
+        stored_patch = re.sub(b'\r\n?', b'\n', self.patch)
+        calculated_patch = re.sub(b'\r\n?', b'\n', calculated_patch)
         # Strip trailing whitespace
-        calculated_patch = re.sub(' *\n', '\n', calculated_patch)
-        stored_patch = re.sub(' *\n', '\n', stored_patch)
+        calculated_patch = re.sub(b' *\n', b'\n', calculated_patch)
+        stored_patch = re.sub(b' *\n', b'\n', stored_patch)
         return (calculated_patch == stored_patch)
 
     def get_merge_request(self, repository):
@@ -685,4 +686,4 @@
 # already merge directives in the wild that used 0.19. Registering with the old
 # format string to retain compatibility with those merge directives.
 _format_registry.register(MergeDirective2,
-                          'Bazaar merge directive format 2 (Bazaar 0.19)')
+                          b'Bazaar merge directive format 2 (Bazaar 0.19)')

=== modified file 'breezy/tests/test_merge.py'
--- breezy/tests/test_merge.py	2018-06-29 17:57:21 +0000
+++ breezy/tests/test_merge.py	2018-07-08 14:45:27 +0000
@@ -37,6 +37,7 @@
 from ..errors import UnrelatedBranches, NoCommits
 from ..merge import transform_tree, merge_inner, _PlanMerge
 from ..osutils import basename, pathjoin, file_kind
+from ..sixish import int2byte
 from . import (
     features,
     TestCaseWithMemoryTransport,
@@ -374,22 +375,22 @@
     def test_weave_cherrypick(self):
         this_tree, other_tree = self.prepare_cherrypick()
         merger = _mod_merge.Merger.from_revision_ids(
-            this_tree, 'rev3b', 'rev2b', other_tree.branch)
+            this_tree, b'rev3b', b'rev2b', other_tree.branch)
         merger.merge_type = _mod_merge.WeaveMerger
         merger.do_merge()
-        self.assertFileEqual('c\na\n', 'this/file')
+        self.assertFileEqual(b'c\na\n', 'this/file')
 
     def test_weave_cannot_reverse_cherrypick(self):
         this_tree, other_tree = self.prepare_cherrypick()
         merger = _mod_merge.Merger.from_revision_ids(
-            this_tree, 'rev2b', 'rev3b', other_tree.branch)
+            this_tree, b'rev2b', b'rev3b', other_tree.branch)
         merger.merge_type = _mod_merge.WeaveMerger
         self.assertRaises(errors.CannotReverseCherrypick, merger.do_merge)
 
     def test_merge3_can_reverse_cherrypick(self):
         this_tree, other_tree = self.prepare_cherrypick()
         merger = _mod_merge.Merger.from_revision_ids(
-            this_tree, 'rev2b', 'rev3b', other_tree.branch)
+            this_tree, b'rev2b', b'rev3b', other_tree.branch)
         merger.merge_type = _mod_merge.Merge3Merger
         merger.do_merge()
 
@@ -407,14 +408,14 @@
         self.addCleanup(this_tree.unlock)
 
         merger = _mod_merge.Merger.from_revision_ids(
-            this_tree, 'rev3b', 'rev2b', other_tree.branch)
+            this_tree, b'rev3b', b'rev2b', other_tree.branch)
         merger.merge_type = _mod_merge.Merge3Merger
         merger.do_merge()
-        self.assertFileEqual('a\n'
-                             '<<<<<<< TREE\n'
-                             '=======\n'
-                             'c\n'
-                             '>>>>>>> MERGE-SOURCE\n',
+        self.assertFileEqual(b'a\n'
+                             b'<<<<<<< TREE\n'
+                             b'=======\n'
+                             b'c\n'
+                             b'>>>>>>> MERGE-SOURCE\n',
                              'this/file')
 
     def test_merge_reverse_revision_range(self):
@@ -445,13 +446,13 @@
         this_tree.lock_write()
         self.addCleanup(this_tree.unlock)
         merger = _mod_merge.Merger.from_revision_ids(
-            this_tree, 'rev2b', other_branch=other_tree.branch)
+            this_tree, b'rev2b', other_branch=other_tree.branch)
         merger.merge_type = _mod_merge.Merge3Merger
         tree_merger = merger.make_merger()
         self.assertIs(_mod_merge.Merge3Merger, tree_merger.__class__)
-        self.assertEqual('rev2b',
+        self.assertEqual(b'rev2b',
             tree_merger.other_tree.get_revision_id())
-        self.assertEqual('rev1',
+        self.assertEqual(b'rev1',
             tree_merger.base_tree.get_revision_id())
         self.assertEqual(other_tree.branch, tree_merger.other_branch)
 
@@ -474,16 +475,10 @@
         tt = tree_merger.make_preview_transform()
         self.addCleanup(tt.finalize)
         preview_tree = tt.get_preview_tree()
-        tree_file = this_tree.get_file('file')
-        try:
-            self.assertEqual('1\n2a\n', tree_file.read())
-        finally:
-            tree_file.close()
-        preview_file = preview_tree.get_file('file')
-        try:
-            self.assertEqual('2b\n1\n2a\n', preview_file.read())
-        finally:
-            preview_file.close()
+        with this_tree.get_file('file') as tree_file:
+            self.assertEqual(b'1\n2a\n', tree_file.read())
+        with preview_tree.get_file('file') as preview_file:
+            self.assertEqual(b'2b\n1\n2a\n', preview_file.read())
 
     def test_do_merge(self):
         this_tree = self.make_branch_and_tree('this')
@@ -566,7 +561,7 @@
         self.plan_merge_vf.fallback_versionedfiles.append(self.vf)
 
     def add_version(self, key, parents, text):
-        self.vf.add_lines(key, parents, [c+'\n' for c in text])
+        self.vf.add_lines(key, parents, [int2byte(c)+b'\n' for c in bytearray(text)])
 
     def add_rev(self, prefix, revision_id, parents, text):
         self.add_version((prefix, revision_id), [(prefix, p) for p in parents],
@@ -577,72 +572,72 @@
                                      [c+'\n' for c in text])
 
     def setup_plan_merge(self):
-        self.add_rev('root', 'A', [], 'abc')
-        self.add_rev('root', 'B', ['A'], 'acehg')
-        self.add_rev('root', 'C', ['A'], 'fabg')
-        return _PlanMerge('B', 'C', self.plan_merge_vf, ('root',))
+        self.add_rev(b'root', b'A', [], b'abc')
+        self.add_rev(b'root', b'B', [b'A'], b'acehg')
+        self.add_rev(b'root', b'C', [b'A'], b'fabg')
+        return _PlanMerge(b'B', b'C', self.plan_merge_vf, (b'root',))
 
     def setup_plan_merge_uncommitted(self):
-        self.add_version(('root', 'A'), [], 'abc')
-        self.add_uncommitted_version(('root', 'B:'), [('root', 'A')], 'acehg')
-        self.add_uncommitted_version(('root', 'C:'), [('root', 'A')], 'fabg')
-        return _PlanMerge('B:', 'C:', self.plan_merge_vf, ('root',))
+        self.add_version((b'root', b'A'), [], b'abc')
+        self.add_uncommitted_version((b'root', b'B:'), [(b'root', b'A')], b'acehg')
+        self.add_uncommitted_version((b'root', b'C:'), [(b'root', b'A')], b'fabg')
+        return _PlanMerge(b'B:', b'C:', self.plan_merge_vf, (b'root',))
 
     def test_base_from_plan(self):
         self.setup_plan_merge()
-        plan = self.plan_merge_vf.plan_merge('B', 'C')
+        plan = self.plan_merge_vf.plan_merge(b'B', b'C')
         pwm = versionedfile.PlanWeaveMerge(plan)
-        self.assertEqual(['a\n', 'b\n', 'c\n'], pwm.base_from_plan())
+        self.assertEqual([b'a\n', b'b\n', b'c\n'], pwm.base_from_plan())
 
     def test_unique_lines(self):
         plan = self.setup_plan_merge()
         self.assertEqual(plan._unique_lines(
-            plan._get_matching_blocks('B', 'C')),
+            plan._get_matching_blocks(b'B', b'C')),
             ([1, 2, 3], [0, 2]))
 
     def test_plan_merge(self):
         self.setup_plan_merge()
-        plan = self.plan_merge_vf.plan_merge('B', 'C')
+        plan = self.plan_merge_vf.plan_merge(b'B', b'C')
         self.assertEqual([
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-a', 'b\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'e\n'),
-                          ('new-a', 'h\n'),
-                          ('new-a', 'g\n'),
-                          ('new-b', 'g\n')],
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-a', b'b\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'e\n'),
+                          ('new-a', b'h\n'),
+                          ('new-a', b'g\n'),
+                          ('new-b', b'g\n')],
                          list(plan))
 
     def test_plan_merge_cherrypick(self):
-        self.add_rev('root', 'A', [], 'abc')
-        self.add_rev('root', 'B', ['A'], 'abcde')
-        self.add_rev('root', 'C', ['A'], 'abcefg')
-        self.add_rev('root', 'D', ['A', 'B', 'C'], 'abcdegh')
-        my_plan = _PlanMerge('B', 'D', self.plan_merge_vf, ('root',))
+        self.add_rev(b'root', b'A', [], b'abc')
+        self.add_rev(b'root', b'B', [b'A'], b'abcde')
+        self.add_rev(b'root', b'C', [b'A'], b'abcefg')
+        self.add_rev(b'root', b'D', [b'A', b'B', b'C'], b'abcdegh')
+        my_plan = _PlanMerge(b'B', b'D', self.plan_merge_vf, (b'root',))
         # We shortcut when one text supersedes the other in the per-file graph.
         # We don't actually need to compare the texts at this point.
         self.assertEqual([
-                          ('new-b', 'a\n'),
-                          ('new-b', 'b\n'),
-                          ('new-b', 'c\n'),
-                          ('new-b', 'd\n'),
-                          ('new-b', 'e\n'),
-                          ('new-b', 'g\n'),
-                          ('new-b', 'h\n')],
+                          ('new-b', b'a\n'),
+                          ('new-b', b'b\n'),
+                          ('new-b', b'c\n'),
+                          ('new-b', b'd\n'),
+                          ('new-b', b'e\n'),
+                          ('new-b', b'g\n'),
+                          ('new-b', b'h\n')],
                           list(my_plan.plan_merge()))
 
     def test_plan_merge_no_common_ancestor(self):
-        self.add_rev('root', 'A', [], 'abc')
-        self.add_rev('root', 'B', [], 'xyz')
-        my_plan = _PlanMerge('A', 'B', self.plan_merge_vf, ('root',))
+        self.add_rev(b'root', b'A', [], b'abc')
+        self.add_rev(b'root', b'B', [], b'xyz')
+        my_plan = _PlanMerge(b'A', b'B', self.plan_merge_vf, (b'root',))
         self.assertEqual([
-                          ('new-a', 'a\n'),
-                          ('new-a', 'b\n'),
-                          ('new-a', 'c\n'),
-                          ('new-b', 'x\n'),
-                          ('new-b', 'y\n'),
-                          ('new-b', 'z\n')],
+                          ('new-a', b'a\n'),
+                          ('new-a', b'b\n'),
+                          ('new-a', b'c\n'),
+                          ('new-b', b'x\n'),
+                          ('new-b', b'y\n'),
+                          ('new-b', b'z\n')],
                           list(my_plan.plan_merge()))
 
     def test_plan_merge_tail_ancestors(self):
@@ -665,35 +660,35 @@
         # are already present in E
 
         # Introduce the base text
-        self.add_rev('root', 'A', [], 'abc')
+        self.add_rev(b'root', b'A', [], b'abc')
         # Introduces a new line B
-        self.add_rev('root', 'B', ['A'], 'aBbc')
+        self.add_rev(b'root', b'B', [b'A'], b'aBbc')
         # Introduces a new line C
-        self.add_rev('root', 'C', ['A'], 'abCc')
+        self.add_rev(b'root', b'C', [b'A'], b'abCc')
         # Introduce new line D
-        self.add_rev('root', 'D', ['B'], 'DaBbc')
+        self.add_rev(b'root', b'D', [b'B'], b'DaBbc')
         # Merges B and C by just incorporating both
-        self.add_rev('root', 'E', ['B', 'C'], 'aBbCc')
+        self.add_rev(b'root', b'E', [b'B', b'C'], b'aBbCc')
         # Introduce new line F
-        self.add_rev('root', 'F', ['C'], 'abCcF')
+        self.add_rev(b'root', b'F', [b'C'], b'abCcF')
         # Merge D & E by just combining the texts
-        self.add_rev('root', 'G', ['D', 'E'], 'DaBbCc')
+        self.add_rev(b'root', b'G', [b'D', b'E'], b'DaBbCc')
         # Merge F & E by just combining the texts
-        self.add_rev('root', 'H', ['F', 'E'], 'aBbCcF')
+        self.add_rev(b'root', b'H', [b'F', b'E'], b'aBbCcF')
         # Merge G & H by just combining texts
-        self.add_rev('root', 'I', ['G', 'H'], 'DaBbCcF')
+        self.add_rev(b'root', b'I', [b'G', b'H'], b'DaBbCcF')
         # Merge G & H but supersede an old line in B
-        self.add_rev('root', 'J', ['H', 'G'], 'DaJbCcF')
-        plan = self.plan_merge_vf.plan_merge('I', 'J')
+        self.add_rev(b'root', b'J', [b'H', b'G'], b'DaJbCcF')
+        plan = self.plan_merge_vf.plan_merge(b'I', b'J')
         self.assertEqual([
-                          ('unchanged', 'D\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-b', 'B\n'),
-                          ('new-b', 'J\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'C\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'F\n')],
+                          ('unchanged', b'D\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-b', b'B\n'),
+                          ('new-b', b'J\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'C\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'F\n')],
                          list(plan))
 
     def test_plan_merge_tail_triple_ancestors(self):
@@ -714,28 +709,28 @@
         # a third LCA that doesn't add new lines, but will trigger our more
         # involved ancestry logic
 
-        self.add_rev('root', 'A', [], 'abc')
-        self.add_rev('root', 'B', ['A'], 'aBbc')
-        self.add_rev('root', 'C', ['A'], 'abCc')
-        self.add_rev('root', 'D', ['B'], 'DaBbc')
-        self.add_rev('root', 'E', ['B', 'C'], 'aBbCc')
-        self.add_rev('root', 'F', ['C'], 'abCcF')
-        self.add_rev('root', 'G', ['D', 'E'], 'DaBbCc')
-        self.add_rev('root', 'H', ['F', 'E'], 'aBbCcF')
-        self.add_rev('root', 'Q', ['E'], 'aBbCc')
-        self.add_rev('root', 'I', ['G', 'Q', 'H'], 'DaBbCcF')
+        self.add_rev(b'root', b'A', [], b'abc')
+        self.add_rev(b'root', b'B', [b'A'], b'aBbc')
+        self.add_rev(b'root', b'C', [b'A'], b'abCc')
+        self.add_rev(b'root', b'D', [b'B'], b'DaBbc')
+        self.add_rev(b'root', b'E', [b'B', b'C'], b'aBbCc')
+        self.add_rev(b'root', b'F', [b'C'], 'abCcF')
+        self.add_rev(b'root', b'G', [b'D', b'E'], b'DaBbCc')
+        self.add_rev(b'root', b'H', [b'F', b'E'], b'aBbCcF')
+        self.add_rev(b'root', b'Q', [b'E'], 'aBbCc')
+        self.add_rev(b'root', b'I', [b'G', b'Q', b'H'], b'DaBbCcF')
         # Merge G & H but supersede an old line in B
-        self.add_rev('root', 'J', ['H', 'Q', 'G'], 'DaJbCcF')
-        plan = self.plan_merge_vf.plan_merge('I', 'J')
+        self.add_rev(b'root', b'J', [b'H', b'Q', b'G'], b'DaJbCcF')
+        plan = self.plan_merge_vf.plan_merge(b'I', b'J')
         self.assertEqual([
-                          ('unchanged', 'D\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-b', 'B\n'),
-                          ('new-b', 'J\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'C\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'F\n')],
+                          ('unchanged', b'D\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-b', b'B\n'),
+                          ('new-b', b'J\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'C\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'F\n')],
                          list(plan))
 
     def test_plan_merge_2_tail_triple_ancestors(self):
@@ -754,42 +749,42 @@
         # This is meant to test after hitting a 3-way LCA, and multiple tail
         # ancestors (only have NULL_REVISION in common)
 
-        self.add_rev('root', 'A', [], 'abc')
-        self.add_rev('root', 'B', [], 'def')
-        self.add_rev('root', 'D', ['A'], 'Dabc')
-        self.add_rev('root', 'E', ['A', 'B'], 'abcdef')
-        self.add_rev('root', 'F', ['B'], 'defF')
-        self.add_rev('root', 'G', ['D', 'E'], 'Dabcdef')
-        self.add_rev('root', 'H', ['F', 'E'], 'abcdefF')
-        self.add_rev('root', 'Q', ['E'], 'abcdef')
-        self.add_rev('root', 'I', ['G', 'Q', 'H'], 'DabcdefF')
+        self.add_rev(b'root', b'A', [], b'abc')
+        self.add_rev(b'root', b'B', [], b'def')
+        self.add_rev(b'root', b'D', [b'A'], b'Dabc')
+        self.add_rev(b'root', b'E', [b'A', b'B'], b'abcdef')
+        self.add_rev(b'root', b'F', [b'B'], b'defF')
+        self.add_rev(b'root', b'G', [b'D', b'E'], b'Dabcdef')
+        self.add_rev(b'root', b'H', [b'F', b'E'], b'abcdefF')
+        self.add_rev(b'root', b'Q', [b'E'], b'abcdef')
+        self.add_rev(b'root', b'I', [b'G', b'Q', b'H'], b'DabcdefF')
         # Merge G & H but supersede an old line in B
-        self.add_rev('root', 'J', ['H', 'Q', 'G'], 'DabcdJfF')
-        plan = self.plan_merge_vf.plan_merge('I', 'J')
+        self.add_rev(b'root', b'J', [b'H', b'Q', b'G'], b'DabcdJfF')
+        plan = self.plan_merge_vf.plan_merge(b'I', b'J')
         self.assertEqual([
-                          ('unchanged', 'D\n'),
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('killed-b', 'e\n'),
-                          ('new-b', 'J\n'),
-                          ('unchanged', 'f\n'),
-                          ('unchanged', 'F\n')],
+                          ('unchanged', b'D\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('killed-b', b'e\n'),
+                          ('new-b', b'J\n'),
+                          ('unchanged', b'f\n'),
+                          ('unchanged', b'F\n')],
                          list(plan))
 
     def test_plan_merge_uncommitted_files(self):
         self.setup_plan_merge_uncommitted()
-        plan = self.plan_merge_vf.plan_merge('B:', 'C:')
+        plan = self.plan_merge_vf.plan_merge(b'B:', b'C:')
         self.assertEqual([
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-a', 'b\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'e\n'),
-                          ('new-a', 'h\n'),
-                          ('new-a', 'g\n'),
-                          ('new-b', 'g\n')],
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-a', b'b\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'e\n'),
+                          ('new-a', b'h\n'),
+                          ('new-a', b'g\n'),
+                          ('new-b', b'g\n')],
                          list(plan))
 
     def test_plan_merge_insert_order(self):
@@ -800,52 +795,52 @@
         same ordering, then the lines match the parents, if they don't only
         *some* of the lines match.
         """
-        self.add_rev('root', 'A', [], 'abcdef')
-        self.add_rev('root', 'B', ['A'], 'abwxcdef')
-        self.add_rev('root', 'C', ['A'], 'abyzcdef')
+        self.add_rev(b'root', b'A', [], b'abcdef')
+        self.add_rev(b'root', b'B', [b'A'], b'abwxcdef')
+        self.add_rev(b'root', b'C', [b'A'], b'abyzcdef')
         # Merge, and resolve the conflict by adding *both* sets of lines
         # If we get the ordering wrong, these will look like new lines in D,
         # rather than carried over from B, C
-        self.add_rev('root', 'D', ['B', 'C'],
-                         'abwxyzcdef')
+        self.add_rev(b'root', b'D', [b'B', b'C'],
+                         b'abwxyzcdef')
         # Supersede the lines in B and delete the lines in C, which will
         # conflict if they are treated as being in D
-        self.add_rev('root', 'E', ['C', 'B'],
-                         'abnocdef')
+        self.add_rev(b'root', b'E', [b'C', b'B'],
+                         b'abnocdef')
         # Same thing for the lines in C
-        self.add_rev('root', 'F', ['C'], 'abpqcdef')
-        plan = self.plan_merge_vf.plan_merge('D', 'E')
+        self.add_rev(b'root', b'F', [b'C'], b'abpqcdef')
+        plan = self.plan_merge_vf.plan_merge(b'D', b'E')
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('killed-b', 'w\n'),
-                          ('killed-b', 'x\n'),
-                          ('killed-b', 'y\n'),
-                          ('killed-b', 'z\n'),
-                          ('new-b', 'n\n'),
-                          ('new-b', 'o\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n')],
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('killed-b', b'w\n'),
+                          ('killed-b', b'x\n'),
+                          ('killed-b', b'y\n'),
+                          ('killed-b', b'z\n'),
+                          ('new-b', b'n\n'),
+                          ('new-b', b'o\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n')],
                          list(plan))
-        plan = self.plan_merge_vf.plan_merge('E', 'D')
+        plan = self.plan_merge_vf.plan_merge(b'E', b'D')
         # Going in the opposite direction shows the effect of the opposite plan
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('new-b', 'w\n'),
-                          ('new-b', 'x\n'),
-                          ('killed-a', 'y\n'),
-                          ('killed-a', 'z\n'),
-                          ('killed-both', 'w\n'),
-                          ('killed-both', 'x\n'),
-                          ('new-a', 'n\n'),
-                          ('new-a', 'o\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n')],
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('new-b', b'w\n'),
+                          ('new-b', b'x\n'),
+                          ('killed-a', b'y\n'),
+                          ('killed-a', b'z\n'),
+                          ('killed-both', b'w\n'),
+                          ('killed-both', b'x\n'),
+                          ('new-a', b'n\n'),
+                          ('new-a', b'o\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n')],
                          list(plan))
 
     def test_plan_merge_criss_cross(self):
@@ -873,45 +868,45 @@
         #   'foo', it should appear as superseding the value in F (since it
         #   came from B), rather than conflict because of the resolution during
         #   C & D.
-        self.add_rev('root', 'XX', [], 'qrs')
-        self.add_rev('root', 'A', ['XX'], 'abcdef')
-        self.add_rev('root', 'B', ['A'], 'axcdef')
-        self.add_rev('root', 'C', ['B'], 'axcdefg')
-        self.add_rev('root', 'D', ['B'], 'haxcdef')
-        self.add_rev('root', 'E', ['A'], 'abcdyf')
+        self.add_rev(b'root', b'XX', [], b'qrs')
+        self.add_rev(b'root', b'A', [b'XX'], b'abcdef')
+        self.add_rev(b'root', b'B', [b'A'], b'axcdef')
+        self.add_rev(b'root', b'C', [b'B'], b'axcdefg')
+        self.add_rev(b'root', b'D', [b'B'], b'haxcdef')
+        self.add_rev(b'root', b'E', [b'A'], b'abcdyf')
         # Simple combining of all texts
-        self.add_rev('root', 'F', ['C', 'D', 'E'], 'haxcdyfg')
+        self.add_rev(b'root', b'F', [b'C', b'D', b'E'], b'haxcdyfg')
         # combine and supersede 'x'
-        self.add_rev('root', 'G', ['C', 'D', 'E'], 'hazcdyfg')
-        plan = self.plan_merge_vf.plan_merge('F', 'G')
+        self.add_rev(b'root', b'G', [b'C', b'D', b'E'], b'hazcdyfg')
+        plan = self.plan_merge_vf.plan_merge(b'F', b'G')
         self.assertEqual([
-                          ('unchanged', 'h\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-base', 'b\n'),
-                          ('killed-b', 'x\n'),
-                          ('new-b', 'z\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('killed-base', 'e\n'),
-                          ('unchanged', 'y\n'),
-                          ('unchanged', 'f\n'),
-                          ('unchanged', 'g\n')],
+                          ('unchanged', b'h\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-base', b'b\n'),
+                          ('killed-b', b'x\n'),
+                          ('new-b', b'z\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('killed-base', b'e\n'),
+                          ('unchanged', b'y\n'),
+                          ('unchanged', b'f\n'),
+                          ('unchanged', b'g\n')],
                          list(plan))
-        plan = self.plan_merge_vf.plan_lca_merge('F', 'G')
+        plan = self.plan_merge_vf.plan_lca_merge(b'F', b'G')
         # This is one of the main differences between plan_merge and
         # plan_lca_merge. plan_lca_merge generates a conflict for 'x => z',
         # because 'x' was not present in one of the bases. However, in this
         # case it is spurious because 'x' does not exist in the global base A.
         self.assertEqual([
-                          ('unchanged', 'h\n'),
-                          ('unchanged', 'a\n'),
-                          ('conflicted-a', 'x\n'),
-                          ('new-b', 'z\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('unchanged', 'y\n'),
-                          ('unchanged', 'f\n'),
-                          ('unchanged', 'g\n')],
+                          ('unchanged', b'h\n'),
+                          ('unchanged', b'a\n'),
+                          ('conflicted-a', b'x\n'),
+                          ('new-b', b'z\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('unchanged', b'y\n'),
+                          ('unchanged', b'f\n'),
+                          ('unchanged', b'g\n')],
                          list(plan))
 
     def test_criss_cross_flip_flop(self):
@@ -920,88 +915,88 @@
         #       XX      unused ancestor, should not show up in the weave
         #       |
         #       A       Unique LCA
-        #      / \  
+        #      / \
         #     B   C     B & C both introduce a new line
-        #     |\ /|  
-        #     | X |  
-        #     |/ \| 
+        #     |\ /|
+        #     | X |
+        #     |/ \|
         #     D   E     B & C are both merged, so both are common ancestors
         #               In the process of merging, both sides order the new
         #               lines differently
         #
-        self.add_rev('root', 'XX', [], 'qrs')
-        self.add_rev('root', 'A', ['XX'], 'abcdef')
-        self.add_rev('root', 'B', ['A'], 'abcdgef')
-        self.add_rev('root', 'C', ['A'], 'abcdhef')
-        self.add_rev('root', 'D', ['B', 'C'], 'abcdghef')
-        self.add_rev('root', 'E', ['C', 'B'], 'abcdhgef')
-        plan = list(self.plan_merge_vf.plan_merge('D', 'E'))
+        self.add_rev(b'root', b'XX', [], b'qrs')
+        self.add_rev(b'root', b'A', [b'XX'], b'abcdef')
+        self.add_rev(b'root', b'B', [b'A'], b'abcdgef')
+        self.add_rev(b'root', b'C', [b'A'], b'abcdhef')
+        self.add_rev(b'root', b'D', [b'B', b'C'], b'abcdghef')
+        self.add_rev(b'root', b'E', [b'C', b'B'], b'abcdhgef')
+        plan = list(self.plan_merge_vf.plan_merge(b'D', b'E'))
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('new-b', 'h\n'),
-                          ('unchanged', 'g\n'),
-                          ('killed-b', 'h\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('new-b', b'h\n'),
+                          ('unchanged', b'g\n'),
+                          ('killed-b', b'h\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n'),
                          ], plan)
         pwm = versionedfile.PlanWeaveMerge(plan)
-        self.assertEqualDiff('\n'.join('abcdghef') + '\n',
-                             ''.join(pwm.base_from_plan()))
+        self.assertEqualDiff(b'\n'.join(b'abcdghef') + b'\n',
+                             b''.join(pwm.base_from_plan()))
         # Reversing the order reverses the merge plan, and final order of 'hg'
         # => 'gh'
-        plan = list(self.plan_merge_vf.plan_merge('E', 'D'))
+        plan = list(self.plan_merge_vf.plan_merge(b'E', b'D'))
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('new-b', 'g\n'),
-                          ('unchanged', 'h\n'),
-                          ('killed-b', 'g\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('new-b', b'g\n'),
+                          ('unchanged', b'h\n'),
+                          ('killed-b', b'g\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n'),
                          ], plan)
         pwm = versionedfile.PlanWeaveMerge(plan)
-        self.assertEqualDiff('\n'.join('abcdhgef') + '\n',
-                             ''.join(pwm.base_from_plan()))
+        self.assertEqualDiff(b'\n'.join(b'abcdhgef') + b'\n',
+                             b''.join(pwm.base_from_plan()))
         # This is where lca differs, in that it (fairly correctly) determines
         # that there is a conflict because both sides resolved the merge
         # differently
-        plan = list(self.plan_merge_vf.plan_lca_merge('D', 'E'))
+        plan = list(self.plan_merge_vf.plan_lca_merge(b'D', b'E'))
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('conflicted-b', 'h\n'),
-                          ('unchanged', 'g\n'),
-                          ('conflicted-a', 'h\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('conflicted-b', b'h\n'),
+                          ('unchanged', b'g\n'),
+                          ('conflicted-a', b'h\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n'),
                          ], plan)
         pwm = versionedfile.PlanWeaveMerge(plan)
-        self.assertEqualDiff('\n'.join('abcdgef') + '\n',
-                             ''.join(pwm.base_from_plan()))
+        self.assertEqualDiff(b'\n'.join(b'abcdgef') + b'\n',
+                             b''.join(pwm.base_from_plan()))
         # Reversing it changes what line is doubled, but still gives a
         # double-conflict
-        plan = list(self.plan_merge_vf.plan_lca_merge('E', 'D'))
+        plan = list(self.plan_merge_vf.plan_lca_merge(b'E', b'D'))
         self.assertEqual([
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('unchanged', 'd\n'),
-                          ('conflicted-b', 'g\n'),
-                          ('unchanged', 'h\n'),
-                          ('conflicted-a', 'g\n'),
-                          ('unchanged', 'e\n'),
-                          ('unchanged', 'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('unchanged', b'd\n'),
+                          ('conflicted-b', b'g\n'),
+                          ('unchanged', b'h\n'),
+                          ('conflicted-a', b'g\n'),
+                          ('unchanged', b'e\n'),
+                          ('unchanged', b'f\n'),
                          ], plan)
         pwm = versionedfile.PlanWeaveMerge(plan)
-        self.assertEqualDiff('\n'.join('abcdhef') + '\n',
-                             ''.join(pwm.base_from_plan()))
+        self.assertEqualDiff(b'\n'.join(b'abcdhef') + b'\n',
+                             b''.join(pwm.base_from_plan()))
 
     def assertRemoveExternalReferences(self, filtered_parent_map,
                                        child_map, tails, parent_map):
@@ -1076,134 +1071,134 @@
 
     def test_subtract_plans(self):
         old_plan = [
-        ('unchanged', 'a\n'),
-        ('new-a', 'b\n'),
-        ('killed-a', 'c\n'),
-        ('new-b', 'd\n'),
-        ('new-b', 'e\n'),
-        ('killed-b', 'f\n'),
-        ('killed-b', 'g\n'),
+        ('unchanged', b'a\n'),
+        ('new-a', b'b\n'),
+        ('killed-a', b'c\n'),
+        ('new-b', b'd\n'),
+        ('new-b', b'e\n'),
+        ('killed-b', b'f\n'),
+        ('killed-b', b'g\n'),
         ]
         new_plan = [
-        ('unchanged', 'a\n'),
-        ('new-a', 'b\n'),
-        ('killed-a', 'c\n'),
-        ('new-b', 'd\n'),
-        ('new-b', 'h\n'),
-        ('killed-b', 'f\n'),
-        ('killed-b', 'i\n'),
+        ('unchanged', b'a\n'),
+        ('new-a', b'b\n'),
+        ('killed-a', b'c\n'),
+        ('new-b', b'd\n'),
+        ('new-b', b'h\n'),
+        ('killed-b', b'f\n'),
+        ('killed-b', b'i\n'),
         ]
         subtracted_plan = [
-        ('unchanged', 'a\n'),
-        ('new-a', 'b\n'),
-        ('killed-a', 'c\n'),
-        ('new-b', 'h\n'),
-        ('unchanged', 'f\n'),
-        ('killed-b', 'i\n'),
+        ('unchanged', b'a\n'),
+        ('new-a', b'b\n'),
+        ('killed-a', b'c\n'),
+        ('new-b', b'h\n'),
+        ('unchanged', b'f\n'),
+        ('killed-b', b'i\n'),
         ]
         self.assertEqual(subtracted_plan,
             list(_PlanMerge._subtract_plans(old_plan, new_plan)))
 
     def setup_merge_with_base(self):
-        self.add_rev('root', 'COMMON', [], 'abc')
-        self.add_rev('root', 'THIS', ['COMMON'], 'abcd')
-        self.add_rev('root', 'BASE', ['COMMON'], 'eabc')
-        self.add_rev('root', 'OTHER', ['BASE'], 'eafb')
+        self.add_rev(b'root', b'COMMON', [], b'abc')
+        self.add_rev(b'root', b'THIS', [b'COMMON'], b'abcd')
+        self.add_rev(b'root', b'BASE', [b'COMMON'], b'eabc')
+        self.add_rev(b'root', b'OTHER', [b'BASE'], b'eafb')
 
     def test_plan_merge_with_base(self):
         self.setup_merge_with_base()
-        plan = self.plan_merge_vf.plan_merge('THIS', 'OTHER', 'BASE')
-        self.assertEqual([('unchanged', 'a\n'),
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'b\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'd\n')
+        plan = self.plan_merge_vf.plan_merge(b'THIS', b'OTHER', b'BASE')
+        self.assertEqual([('unchanged', b'a\n'),
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'b\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'd\n')
                          ], list(plan))
 
     def test_plan_lca_merge(self):
         self.setup_plan_merge()
-        plan = self.plan_merge_vf.plan_lca_merge('B', 'C')
+        plan = self.plan_merge_vf.plan_lca_merge(b'B', b'C')
         self.assertEqual([
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'e\n'),
-                          ('new-a', 'h\n'),
-                          ('killed-a', 'b\n'),
-                          ('unchanged', 'g\n')],
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'e\n'),
+                          ('new-a', b'h\n'),
+                          ('killed-a', b'b\n'),
+                          ('unchanged', b'g\n')],
                          list(plan))
 
     def test_plan_lca_merge_uncommitted_files(self):
         self.setup_plan_merge_uncommitted()
-        plan = self.plan_merge_vf.plan_lca_merge('B:', 'C:')
+        plan = self.plan_merge_vf.plan_lca_merge(b'B:', b'C:')
         self.assertEqual([
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'a\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'e\n'),
-                          ('new-a', 'h\n'),
-                          ('killed-a', 'b\n'),
-                          ('unchanged', 'g\n')],
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'e\n'),
+                          ('new-a', b'h\n'),
+                          ('killed-a', b'b\n'),
+                          ('unchanged', b'g\n')],
                          list(plan))
 
     def test_plan_lca_merge_with_base(self):
         self.setup_merge_with_base()
-        plan = self.plan_merge_vf.plan_lca_merge('THIS', 'OTHER', 'BASE')
-        self.assertEqual([('unchanged', 'a\n'),
-                          ('new-b', 'f\n'),
-                          ('unchanged', 'b\n'),
-                          ('killed-b', 'c\n'),
-                          ('new-a', 'd\n')
+        plan = self.plan_merge_vf.plan_lca_merge(b'THIS', b'OTHER', b'BASE')
+        self.assertEqual([('unchanged', b'a\n'),
+                          ('new-b', b'f\n'),
+                          ('unchanged', b'b\n'),
+                          ('killed-b', b'c\n'),
+                          ('new-a', b'd\n')
                          ], list(plan))
 
     def test_plan_lca_merge_with_criss_cross(self):
-        self.add_version(('root', 'ROOT'), [], 'abc')
+        self.add_version((b'root', b'ROOT'), [], b'abc')
         # each side makes a change
-        self.add_version(('root', 'REV1'), [('root', 'ROOT')], 'abcd')
-        self.add_version(('root', 'REV2'), [('root', 'ROOT')], 'abce')
+        self.add_version((b'root', b'REV1'), [(b'root', b'ROOT')], b'abcd')
+        self.add_version((b'root', b'REV2'), [(b'root', b'ROOT')], b'abce')
         # both sides merge, discarding others' changes
-        self.add_version(('root', 'LCA1'),
-            [('root', 'REV1'), ('root', 'REV2')], 'abcd')
-        self.add_version(('root', 'LCA2'),
-            [('root', 'REV1'), ('root', 'REV2')], 'fabce')
-        plan = self.plan_merge_vf.plan_lca_merge('LCA1', 'LCA2')
-        self.assertEqual([('new-b', 'f\n'),
-                          ('unchanged', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('unchanged', 'c\n'),
-                          ('conflicted-a', 'd\n'),
-                          ('conflicted-b', 'e\n'),
+        self.add_version((b'root', b'LCA1'),
+            [(b'root', b'REV1'), (b'root', b'REV2')], b'abcd')
+        self.add_version((b'root', b'LCA2'),
+            [(b'root', b'REV1'), (b'root', b'REV2')], b'fabce')
+        plan = self.plan_merge_vf.plan_lca_merge(b'LCA1', b'LCA2')
+        self.assertEqual([('new-b', b'f\n'),
+                          ('unchanged', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('unchanged', b'c\n'),
+                          ('conflicted-a', b'd\n'),
+                          ('conflicted-b', b'e\n'),
                          ], list(plan))
 
     def test_plan_lca_merge_with_null(self):
-        self.add_version(('root', 'A'), [], 'ab')
-        self.add_version(('root', 'B'), [], 'bc')
-        plan = self.plan_merge_vf.plan_lca_merge('A', 'B')
-        self.assertEqual([('new-a', 'a\n'),
-                          ('unchanged', 'b\n'),
-                          ('new-b', 'c\n'),
+        self.add_version((b'root', b'A'), [], b'ab')
+        self.add_version((b'root', b'B'), [], b'bc')
+        plan = self.plan_merge_vf.plan_lca_merge(b'A', b'B')
+        self.assertEqual([('new-a', b'a\n'),
+                          ('unchanged', b'b\n'),
+                          ('new-b', b'c\n'),
                          ], list(plan))
 
     def test_plan_merge_with_delete_and_change(self):
-        self.add_rev('root', 'C', [], 'a')
-        self.add_rev('root', 'A', ['C'], 'b')
-        self.add_rev('root', 'B', ['C'], '')
-        plan = self.plan_merge_vf.plan_merge('A', 'B')
-        self.assertEqual([('killed-both', 'a\n'),
-                          ('new-a', 'b\n'),
+        self.add_rev(b'root', b'C', [], b'a')
+        self.add_rev(b'root', b'A', [b'C'], b'b')
+        self.add_rev(b'root', b'B', [b'C'], b'')
+        plan = self.plan_merge_vf.plan_merge(b'A', b'B')
+        self.assertEqual([('killed-both', b'a\n'),
+                          ('new-a', b'b\n'),
                          ], list(plan))
 
     def test_plan_merge_with_move_and_change(self):
-        self.add_rev('root', 'C', [], 'abcd')
-        self.add_rev('root', 'A', ['C'], 'acbd')
-        self.add_rev('root', 'B', ['C'], 'aBcd')
-        plan = self.plan_merge_vf.plan_merge('A', 'B')
-        self.assertEqual([('unchanged', 'a\n'),
-                          ('new-a', 'c\n'),
-                          ('killed-b', 'b\n'),
-                          ('new-b', 'B\n'),
-                          ('killed-a', 'c\n'),
-                          ('unchanged', 'd\n'),
+        self.add_rev(b'root', b'C', [], b'abcd')
+        self.add_rev(b'root', b'A', [b'C'], b'acbd')
+        self.add_rev(b'root', b'B', [b'C'], b'aBcd')
+        plan = self.plan_merge_vf.plan_merge(b'A', b'B')
+        self.assertEqual([('unchanged', b'a\n'),
+                          ('new-a', b'c\n'),
+                          ('killed-b', b'b\n'),
+                          ('new-b', b'B\n'),
+                          ('killed-a', b'c\n'),
+                          ('unchanged', b'd\n'),
                          ], list(plan))
 
 
@@ -1403,7 +1398,7 @@
         builder = self.get_builder()
         builder.build_snapshot(None,
             [('add', (u'', b'a-root-id', 'directory', None)),
-             ('add', (u'a', b'a-id', 'file', 'a\nb\nc\n'))],
+             ('add', (u'a', b'a-id', 'file', b'a\nb\nc\n'))],
             revision_id=b'A-id')
         builder.build_snapshot([b'A-id'],
             [('modify', ('a', b'a\nb\nC\nc\n'))],
@@ -1833,7 +1828,7 @@
             [('modify', ('foo', b'B content\n'))],
             revision_id=b'B-id')
         builder.build_snapshot([b'A-id'],
-            [('modify', ('foo', 'C content\n'))],
+            [('modify', ('foo', b'C content\n'))],
             revision_id=b'C-id')
         builder.build_snapshot([b'C-id', b'B-id'], [], revision_id=b'E-id')
         builder.build_snapshot([b'B-id', b'C-id'], [], revision_id=b'D-id')
@@ -1865,7 +1860,7 @@
              ('add', (u'foo', b'foo-id', 'file', b'A content\n'))],
             revision_id=b'A-id')
         builder.build_snapshot([b'A-id'],
-            [('modify', ('foo', 'B content\n'))],
+            [('modify', ('foo', b'B content\n'))],
             revision_id=b'B-id')
         builder.build_snapshot([b'A-id'],
             [('modify', ('foo', b'C content\n'))],
@@ -2031,8 +2026,8 @@
         builder.build_snapshot([b'A-id'], [], revision_id=b'B-id')
         builder.build_snapshot([b'A-id'], [], revision_id=b'C-id')
         builder.build_snapshot([b'C-id', b'B-id'],
-            [('modify', ('a', 'new-content\n')),
-             ('modify', ('b', 'new-content\n'))],
+            [('modify', ('a', b'new-content\n')),
+             ('modify', ('b', b'new-content\n'))],
             revision_id=b'E-id')
         builder.build_snapshot([b'B-id', b'C-id'],
             [('rename', ('b', 'c'))],
@@ -2626,7 +2621,7 @@
         builder = self.get_builder()
         builder.build_snapshot(None,
             [('add', (u'', b'a-root-id', 'directory', None)),
-             ('add', (u'foo', b'foo-id', 'file', 'a\nb\nc\n'))],
+             ('add', (u'foo', b'foo-id', 'file', b'a\nb\nc\n'))],
             revision_id=b'A-id')
         builder.build_snapshot([b'A-id'], [], revision_id=b'C-id')
         builder.build_snapshot([b'A-id'],
@@ -2764,7 +2759,7 @@
         wt.set_last_revision(b'A-id')
         wt.branch.set_last_revision_info(1, b'A-id')
         wt.commit('C', rev_id=b'C-id', recursive=None)
-        wt.merge_from_branch(wt.branch, to_revision='B-id')
+        wt.merge_from_branch(wt.branch, to_revision=b'B-id')
         wt.commit('E', rev_id=b'E-id', recursive=None)
         wt.set_parent_ids([b'B-id', b'C-id'])
         wt.branch.set_last_revision_info(2, b'B-id')
@@ -2798,7 +2793,7 @@
         wt.set_last_revision(b'A-id')
         wt.branch.set_last_revision_info(1, b'A-id')
         wt.commit('C', rev_id=b'C-id', recursive=None)
-        wt.merge_from_branch(wt.branch, to_revision='B-id')
+        wt.merge_from_branch(wt.branch, to_revision=b'B-id')
         self.build_tree_contents([('tree/sub/file', b'text2')])
         sub_tree.commit('modify contents', rev_id=b'sub-B-id')
         wt.commit('E', rev_id=b'E-id', recursive=None)
@@ -2850,7 +2845,7 @@
         merge_obj = merger.make_merger()
         entries = list(merge_obj._entries_lca())
         root_id = b'a-root-id'
-        self.assertEqual([('sub-tree-root', False,
+        self.assertEqual([(b'sub-tree-root', False,
                            ((u'sub', [u'sub', u'sub']), u'alt_sub', u'sub'),
                            ((root_id, [root_id, root_id]), root_id, root_id),
                            ((u'sub', [u'sub', u'sub']), u'alt_sub', u'sub'),
@@ -2879,7 +2874,7 @@
         wt.set_last_revision(b'A-id')
         wt.branch.set_last_revision_info(1, b'A-id')
         wt.commit('C', rev_id=b'C-id', recursive=None)
-        wt.merge_from_branch(wt.branch, to_revision='B-id')
+        wt.merge_from_branch(wt.branch, to_revision=b'B-id')
         self.build_tree_contents([('tree/sub/file', b'text2')])
         sub_tree.commit('modify contents', rev_id=b'sub-B-id')
         wt.rename_one('sub', 'alt_sub')
@@ -3129,17 +3124,17 @@
         Default is empty tree (just root entry).
         """
         if root_id is None:
-            root_id = ('%s-root-id' % (relpath,)).encode('ascii')
+            root_id = b'%s-root-id' % (relpath.encode('ascii'),)
         wt = self.make_branch_and_tree(relpath)
         wt.set_root_id(root_id)
         if shape is not None:
             adjusted_shape = [relpath + '/' + elem for elem in shape]
             self.build_tree(adjusted_shape)
             ids = [
-                ('%s-%s-id' % (relpath, basename(elem.rstrip('/')))).encode('ascii')
+                (b'%s-%s-id' % (relpath.encode('utf-8'), basename(elem.rstrip('/')).encode('ascii')))
                 for elem in shape]
             wt.add(shape, ids=ids)
-        rev_id = 'r1-%s' % (relpath,)
+        rev_id = b'r1-%s' % (relpath.encode('utf-8'),)
         wt.commit("Initial commit of %s" % (relpath,), rev_id=rev_id)
         self.assertEqual(root_id, wt.path2id(''))
         return wt
@@ -3205,16 +3200,16 @@
         project_wt.lock_read()
         self.addCleanup(project_wt.unlock)
         # The r1-lib1 revision should be merged into this one
-        self.assertEqual(['r1-project', 'r1-lib1'], project_wt.get_parent_ids())
+        self.assertEqual([b'r1-project', b'r1-lib1'], project_wt.get_parent_ids())
         self.assertTreeEntriesEqual(
-            [('', 'project-root-id'),
-             ('README', 'project-README-id'),
-             ('dir', 'project-dir-id'),
-             ('lib1', 'lib1-root-id'),
-             ('dir/file.c', 'project-file.c-id'),
-             ('lib1/Makefile', 'lib1-Makefile-id'),
-             ('lib1/README', 'lib1-README-id'),
-             ('lib1/foo.c', 'lib1-foo.c-id'),
+            [('', b'project-root-id'),
+             ('README', b'project-README-id'),
+             ('dir', b'project-dir-id'),
+             ('lib1', b'lib1-root-id'),
+             ('dir/file.c', b'project-file.c-id'),
+             ('lib1/Makefile', b'lib1-Makefile-id'),
+             ('lib1/README', b'lib1-README-id'),
+             ('lib1/foo.c', b'lib1-foo.c-id'),
             ], project_wt)
 
     def test_subdir(self):
@@ -3224,16 +3219,16 @@
         project_wt.lock_read()
         self.addCleanup(project_wt.unlock)
         # The r1-lib1 revision should be merged into this one
-        self.assertEqual(['r1-project', 'r1-lib1'], project_wt.get_parent_ids())
+        self.assertEqual([b'r1-project', b'r1-lib1'], project_wt.get_parent_ids())
         self.assertTreeEntriesEqual(
-            [('', 'project-root-id'),
-             ('README', 'project-README-id'),
-             ('dir', 'project-dir-id'),
-             ('dir/file.c', 'project-file.c-id'),
-             ('dir/lib1', 'lib1-root-id'),
-             ('dir/lib1/Makefile', 'lib1-Makefile-id'),
-             ('dir/lib1/README', 'lib1-README-id'),
-             ('dir/lib1/foo.c', 'lib1-foo.c-id'),
+            [('', b'project-root-id'),
+             ('README', b'project-README-id'),
+             ('dir', b'project-dir-id'),
+             ('dir/file.c', b'project-file.c-id'),
+             ('dir/lib1', b'lib1-root-id'),
+             ('dir/lib1/Makefile', b'lib1-Makefile-id'),
+             ('dir/lib1/README', b'lib1-README-id'),
+             ('dir/lib1/foo.c', b'lib1-foo.c-id'),
             ], project_wt)
 
     def test_newdir_with_repeat_roots(self):
@@ -3246,18 +3241,18 @@
         project_wt.lock_read()
         self.addCleanup(project_wt.unlock)
         # The r1-lib1 revision should be merged into this one
-        self.assertEqual(['r1-project', 'r1-lib1'], project_wt.get_parent_ids())
+        self.assertEqual([b'r1-project', b'r1-lib1'], project_wt.get_parent_ids())
         new_lib1_id = project_wt.path2id('lib1')
         self.assertNotEqual(None, new_lib1_id)
         self.assertTreeEntriesEqual(
             [('', root_id),
-             ('README', 'project-README-id'),
-             ('dir', 'project-dir-id'),
+             ('README', b'project-README-id'),
+             ('dir', b'project-dir-id'),
              ('lib1', new_lib1_id),
-             ('dir/file.c', 'project-file.c-id'),
-             ('lib1/Makefile', 'lib1-Makefile-id'),
-             ('lib1/README', 'lib1-README-id'),
-             ('lib1/foo.c', 'lib1-foo.c-id'),
+             ('dir/file.c', b'project-file.c-id'),
+             ('lib1/Makefile', b'lib1-Makefile-id'),
+             ('lib1/README', b'lib1-README-id'),
+             ('lib1/foo.c', b'lib1-foo.c-id'),
             ], project_wt)
 
     def test_name_conflict(self):
@@ -3271,13 +3266,13 @@
         dest_wt.lock_read()
         self.addCleanup(dest_wt.unlock)
         # The r1-lib1 revision should be merged into this one
-        self.assertEqual(['r1-dest', 'r1-src'], dest_wt.get_parent_ids())
+        self.assertEqual([b'r1-dest', b'r1-src'], dest_wt.get_parent_ids())
         self.assertTreeEntriesEqual(
-            [('', 'dest-root-id'),
-             ('dir', 'src-root-id'),
-             ('dir.moved', 'dest-dir-id'),
-             ('dir/README', 'src-README-id'),
-             ('dir.moved/file.txt', 'dest-file.txt-id'),
+            [('', b'dest-root-id'),
+             ('dir', b'src-root-id'),
+             ('dir.moved', b'dest-dir-id'),
+             ('dir/README', b'src-README-id'),
+             ('dir.moved/file.txt', b'dest-file.txt-id'),
             ], dest_wt)
 
     def test_file_id_conflict(self):
@@ -3309,11 +3304,11 @@
         self.addCleanup(dest_wt.unlock)
         # The r1-lib1 revision should NOT be merged into this one (this is a
         # partial merge).
-        self.assertEqual(['r1-dest'], dest_wt.get_parent_ids())
+        self.assertEqual([b'r1-dest'], dest_wt.get_parent_ids())
         self.assertTreeEntriesEqual(
-            [('', 'dest-root-id'),
-             ('dir', 'src-dir-id'),
-             ('dir/foo.c', 'src-foo.c-id'),
+            [('', b'dest-root-id'),
+             ('dir', b'src-dir-id'),
+             ('dir/foo.c', b'src-foo.c-id'),
             ], dest_wt)
 
     def test_only_file(self):
@@ -3325,9 +3320,9 @@
         dest_wt.lock_read()
         self.addCleanup(dest_wt.unlock)
         # The r1-lib1 revision should NOT be merged into this one
-        self.assertEqual(['r1-dest'], dest_wt.get_parent_ids())
+        self.assertEqual([b'r1-dest'], dest_wt.get_parent_ids())
         self.assertTreeEntriesEqual(
-            [('', 'dest-root-id'), ('file1.txt', 'two-file-file1.txt-id')],
+            [('', b'dest-root-id'), ('file1.txt', b'two-file-file1.txt-id')],
             dest_wt)
 
     def test_no_such_source_path(self):
@@ -3341,8 +3336,8 @@
         dest_wt.lock_read()
         self.addCleanup(dest_wt.unlock)
         # The dest tree is unmodified.
-        self.assertEqual(['r1-dest'], dest_wt.get_parent_ids())
-        self.assertTreeEntriesEqual([('', 'dest-root-id')], dest_wt)
+        self.assertEqual([b'r1-dest'], dest_wt.get_parent_ids())
+        self.assertTreeEntriesEqual([('', b'dest-root-id')], dest_wt)
 
     def test_no_such_target_path(self):
         """PathNotInTree is also raised if the specified path in the target
@@ -3355,8 +3350,8 @@
         dest_wt.lock_read()
         self.addCleanup(dest_wt.unlock)
         # The dest tree is unmodified.
-        self.assertEqual(['r1-dest'], dest_wt.get_parent_ids())
-        self.assertTreeEntriesEqual([('', 'dest-root-id')], dest_wt)
+        self.assertEqual([b'r1-dest'], dest_wt.get_parent_ids())
+        self.assertTreeEntriesEqual([('', b'dest-root-id')], dest_wt)
 
 
 class TestMergeHooks(TestCaseWithTransport):
@@ -3385,7 +3380,7 @@
                                                    factory, 'test factory')
         self.tree_a.merge_from_branch(self.tree_b.branch)
 
-        self.assertFileEqual("content_3", 'tree_a/file')
+        self.assertFileEqual(b"content_3", 'tree_a/file')
         self.assertLength(1, calls)
 
     def test_post_merge_hook_called(self):
@@ -3398,5 +3393,5 @@
 
         self.tree_a.merge_from_branch(self.tree_b.branch)
 
-        self.assertFileEqual("content_2", 'tree_a/file')
+        self.assertFileEqual(b"content_2", 'tree_a/file')
         self.assertLength(1, calls)

=== modified file 'breezy/tests/test_merge3.py'
--- breezy/tests/test_merge3.py	2018-06-20 10:28:56 +0000
+++ breezy/tests/test_merge3.py	2018-07-08 14:45:27 +0000
@@ -19,9 +19,10 @@
     merge3,
     tests,
     )
-from ..errors import CantReprocessAndShowBase, BinaryFile
+from ..errors import BinaryFile
 from ..sixish import (
     BytesIO,
+    int2byte,
     )
 
 def split_lines(t):
@@ -99,9 +100,9 @@
 
     def test_no_changes(self):
         """No conflicts because nothing changed"""
-        m3 = merge3.Merge3(['aaa', 'bbb'],
-                           ['aaa', 'bbb'],
-                           ['aaa', 'bbb'])
+        m3 = merge3.Merge3([b'aaa', b'bbb'],
+                           [b'aaa', b'bbb'],
+                           [b'aaa', b'bbb'])
 
         self.assertEqual(m3.find_unconflicted(),
                           [(0, 2)])
@@ -116,12 +117,12 @@
                           [('unchanged', 0, 2)])
 
         self.assertEqual(list(m3.merge_groups()),
-                          [('unchanged', ['aaa', 'bbb'])])
+                          [('unchanged', [b'aaa', b'bbb'])])
 
     def test_front_insert(self):
-        m3 = merge3.Merge3(['zz'],
-                           ['aaa', 'bbb', 'zz'],
-                           ['zz'])
+        m3 = merge3.Merge3([b'zz'],
+                           [b'aaa', b'bbb', b'zz'],
+                           [b'zz'])
 
         # todo: should use a sentinal at end as from get_matching_blocks
         # to match without zz
@@ -134,12 +135,12 @@
                            ('unchanged', 0, 1)])
 
         self.assertEqual(list(m3.merge_groups()),
-                          [('a', ['aaa', 'bbb']),
-                           ('unchanged', ['zz'])])
+                          [('a', [b'aaa', b'bbb']),
+                           ('unchanged', [b'zz'])])
 
     def test_null_insert(self):
         m3 = merge3.Merge3([],
-                           ['aaa', 'bbb'],
+                           [b'aaa', b'bbb'],
                            [])
         # todo: should use a sentinal at end as from get_matching_blocks
         # to match without zz
@@ -150,13 +151,13 @@
                           [('a', 0, 2)])
 
         self.assertEqual(list(m3.merge_lines()),
-                          ['aaa', 'bbb'])
+                          [b'aaa', b'bbb'])
 
     def test_no_conflicts(self):
         """No conflicts because only one side changed"""
-        m3 = merge3.Merge3(['aaa', 'bbb'],
-                           ['aaa', '111', 'bbb'],
-                           ['aaa', 'bbb'])
+        m3 = merge3.Merge3([b'aaa', b'bbb'],
+                           [b'aaa', b'111', b'bbb'],
+                           [b'aaa', b'bbb'])
 
         self.assertEqual(m3.find_unconflicted(),
                           [(0, 1), (1, 2)])
@@ -172,41 +173,41 @@
                            ('unchanged', 1, 2),])
 
     def test_append_a(self):
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', 'bbb\n', '222\n'],
-                           ['aaa\n', 'bbb\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'bbb\n', b'222\n'],
+                           [b'aaa\n', b'bbb\n'])
 
-        self.assertEqual(''.join(m3.merge_lines()),
-                          'aaa\nbbb\n222\n')
+        self.assertEqual(b''.join(m3.merge_lines()),
+                          b'aaa\nbbb\n222\n')
 
     def test_append_b(self):
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', 'bbb\n'],
-                           ['aaa\n', 'bbb\n', '222\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'bbb\n', b'222\n'])
 
-        self.assertEqual(''.join(m3.merge_lines()),
-                          'aaa\nbbb\n222\n')
+        self.assertEqual(b''.join(m3.merge_lines()),
+                          b'aaa\nbbb\n222\n')
 
     def test_append_agreement(self):
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', 'bbb\n', '222\n'],
-                           ['aaa\n', 'bbb\n', '222\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'bbb\n', b'222\n'],
+                           [b'aaa\n', b'bbb\n', b'222\n'])
 
-        self.assertEqual(''.join(m3.merge_lines()),
-                          'aaa\nbbb\n222\n')
+        self.assertEqual(b''.join(m3.merge_lines()),
+                          b'aaa\nbbb\n222\n')
 
     def test_append_clash(self):
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', 'bbb\n', '222\n'],
-                           ['aaa\n', 'bbb\n', '333\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'bbb\n', b'222\n'],
+                           [b'aaa\n', b'bbb\n', b'333\n'])
 
-        ml = m3.merge_lines(name_a='a',
-                            name_b='b',
-                            start_marker='<<',
-                            mid_marker='--',
-                            end_marker='>>')
-        self.assertEqual(''.join(ml),
-'''\
+        ml = m3.merge_lines(name_a=b'a',
+                            name_b=b'b',
+                            start_marker=b'<<',
+                            mid_marker=b'--',
+                            end_marker=b'>>')
+        self.assertEqual(b''.join(ml),
+b'''\
 aaa
 bbb
 << a
@@ -217,23 +218,23 @@
 ''')
 
     def test_insert_agreement(self):
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', '222\n', 'bbb\n'],
-                           ['aaa\n', '222\n', 'bbb\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'222\n', b'bbb\n'],
+                           [b'aaa\n', b'222\n', b'bbb\n'])
 
-        ml = m3.merge_lines(name_a='a',
-                            name_b='b',
-                            start_marker='<<',
-                            mid_marker='--',
-                            end_marker='>>')
-        self.assertEqual(''.join(ml), 'aaa\n222\nbbb\n')
+        ml = m3.merge_lines(name_a=b'a',
+                            name_b=b'b',
+                            start_marker=b'<<',
+                            mid_marker=b'--',
+                            end_marker=b'>>')
+        self.assertEqual(b''.join(ml), b'aaa\n222\nbbb\n')
 
 
     def test_insert_clash(self):
         """Both try to insert lines in the same place."""
-        m3 = merge3.Merge3(['aaa\n', 'bbb\n'],
-                           ['aaa\n', '111\n', 'bbb\n'],
-                           ['aaa\n', '222\n', 'bbb\n'])
+        m3 = merge3.Merge3([b'aaa\n', b'bbb\n'],
+                           [b'aaa\n', b'111\n', b'bbb\n'],
+                           [b'aaa\n', b'222\n', b'bbb\n'])
 
         self.assertEqual(m3.find_unconflicted(),
                           [(0, 1), (1, 2)])
@@ -249,9 +250,9 @@
                            ('unchanged', 1, 2)])
 
         self.assertEqual(list(m3.merge_groups()),
-                          [('unchanged', ['aaa\n']),
-                           ('conflict', [], ['111\n'], ['222\n']),
-                           ('unchanged', ['bbb\n']),
+                          [('unchanged', [b'aaa\n']),
+                           ('conflict', [], [b'111\n'], [b'222\n']),
+                           ('unchanged', [b'bbb\n']),
                            ])
 
         ml = m3.merge_lines(name_a=b'a',
@@ -301,136 +302,136 @@
     def test_merge_poem(self):
         """Test case from diff3 manual"""
         m3 = merge3.Merge3(TZU, LAO, TAO)
-        ml = list(m3.merge_lines('LAO', 'TAO'))
+        ml = list(m3.merge_lines(b'LAO', b'TAO'))
         self.log('merge result:')
-        self.log(''.join(ml))
+        self.log(b''.join(ml))
         self.assertEqual(ml, MERGED_RESULT)
 
     def test_minimal_conflicts_common(self):
         """Reprocessing"""
-        base_text = ("a\n" * 20).splitlines(True)
-        this_text = ("a\n"*10+"b\n" * 10).splitlines(True)
-        other_text = ("a\n"*10+"c\n"+"b\n" * 8 + "c\n").splitlines(True)
+        base_text = (b"a\n" * 20).splitlines(True)
+        this_text = (b"a\n"*10+b"b\n" * 10).splitlines(True)
+        other_text = (b"a\n"*10+b"c\n"+b"b\n" * 8 + b"c\n").splitlines(True)
         m3 = merge3.Merge3(base_text, other_text, this_text)
-        m_lines = m3.merge_lines('OTHER', 'THIS', reprocess=True)
-        merged_text = "".join(list(m_lines))
-        optimal_text = ("a\n" * 10 + "<<<<<<< OTHER\nc\n"
-            + 8* "b\n" + "c\n=======\n"
-            + 10*"b\n" + ">>>>>>> THIS\n")
+        m_lines = m3.merge_lines(b'OTHER', b'THIS', reprocess=True)
+        merged_text = b"".join(list(m_lines))
+        optimal_text = (b"a\n" * 10 + b"<<<<<<< OTHER\nc\n"
+            + 8* b"b\n" + b"c\n=======\n"
+            + 10*b"b\n" + b">>>>>>> THIS\n")
         self.assertEqualDiff(optimal_text, merged_text)
 
     def test_minimal_conflicts_unique(self):
         def add_newline(s):
             """Add a newline to each entry in the string"""
-            return [(x+'\n') for x in s]
+            return [(int2byte(x)+b'\n') for x in bytearray(s)]
 
-        base_text = add_newline("abcdefghijklm")
-        this_text = add_newline("abcdefghijklmNOPQRSTUVWXYZ")
-        other_text = add_newline("abcdefghijklm1OPQRSTUVWXY2")
+        base_text = add_newline(b"abcdefghijklm")
+        this_text = add_newline(b"abcdefghijklmNOPQRSTUVWXYZ")
+        other_text = add_newline(b"abcdefghijklm1OPQRSTUVWXY2")
         m3 = merge3.Merge3(base_text, other_text, this_text)
-        m_lines = m3.merge_lines('OTHER', 'THIS', reprocess=True)
-        merged_text = "".join(list(m_lines))
-        optimal_text = ''.join(add_newline("abcdefghijklm")
-            + ["<<<<<<< OTHER\n1\n=======\nN\n>>>>>>> THIS\n"]
-            + add_newline('OPQRSTUVWXY')
-            + ["<<<<<<< OTHER\n2\n=======\nZ\n>>>>>>> THIS\n"]
+        m_lines = m3.merge_lines(b'OTHER', b'THIS', reprocess=True)
+        merged_text = b"".join(list(m_lines))
+        optimal_text = b''.join(add_newline(b"abcdefghijklm")
+            + [b"<<<<<<< OTHER\n1\n=======\nN\n>>>>>>> THIS\n"]
+            + add_newline(b'OPQRSTUVWXY')
+            + [b"<<<<<<< OTHER\n2\n=======\nZ\n>>>>>>> THIS\n"]
             )
         self.assertEqualDiff(optimal_text, merged_text)
 
     def test_minimal_conflicts_nonunique(self):
         def add_newline(s):
             """Add a newline to each entry in the string"""
-            return [(x+'\n') for x in s]
+            return [(int2byte(x)+b'\n') for x in bytearray(s)]
 
-        base_text = add_newline("abacddefgghij")
-        this_text = add_newline("abacddefgghijkalmontfprz")
-        other_text = add_newline("abacddefgghijknlmontfprd")
+        base_text = add_newline(b"abacddefgghij")
+        this_text = add_newline(b"abacddefgghijkalmontfprz")
+        other_text = add_newline(b"abacddefgghijknlmontfprd")
         m3 = merge3.Merge3(base_text, other_text, this_text)
-        m_lines = m3.merge_lines('OTHER', 'THIS', reprocess=True)
-        merged_text = "".join(list(m_lines))
-        optimal_text = ''.join(add_newline("abacddefgghijk")
-            + ["<<<<<<< OTHER\nn\n=======\na\n>>>>>>> THIS\n"]
-            + add_newline('lmontfpr')
-            + ["<<<<<<< OTHER\nd\n=======\nz\n>>>>>>> THIS\n"]
+        m_lines = m3.merge_lines(b'OTHER', b'THIS', reprocess=True)
+        merged_text = b"".join(list(m_lines))
+        optimal_text = b''.join(add_newline(b"abacddefgghijk")
+            + [b"<<<<<<< OTHER\nn\n=======\na\n>>>>>>> THIS\n"]
+            + add_newline(b'lmontfpr')
+            + [b"<<<<<<< OTHER\nd\n=======\nz\n>>>>>>> THIS\n"]
             )
         self.assertEqualDiff(optimal_text, merged_text)
 
     def test_reprocess_and_base(self):
         """Reprocessing and showing base breaks correctly"""
-        base_text = ("a\n" * 20).splitlines(True)
-        this_text = ("a\n"*10+"b\n" * 10).splitlines(True)
-        other_text = ("a\n"*10+"c\n"+"b\n" * 8 + "c\n").splitlines(True)
+        base_text = (b"a\n" * 20).splitlines(True)
+        this_text = (b"a\n"*10+b"b\n" * 10).splitlines(True)
+        other_text = (b"a\n"*10+b"c\n"+b"b\n" * 8 + b"c\n").splitlines(True)
         m3 = merge3.Merge3(base_text, other_text, this_text)
-        m_lines = m3.merge_lines('OTHER', 'THIS', reprocess=True,
-                                 base_marker='|||||||')
-        self.assertRaises(CantReprocessAndShowBase, list, m_lines)
+        m_lines = m3.merge_lines(b'OTHER', b'THIS', reprocess=True,
+                                 base_marker=b'|||||||')
+        self.assertRaises(merge3.CantReprocessAndShowBase, list, m_lines)
 
     def test_binary(self):
-        self.assertRaises(BinaryFile, merge3.Merge3, ['\x00'], ['a'], ['b'])
+        self.assertRaises(BinaryFile, merge3.Merge3, [b'\x00'], [b'a'], [b'b'])
 
     def test_dos_text(self):
-        base_text = 'a\r\n'
-        this_text = 'b\r\n'
-        other_text = 'c\r\n'
+        base_text = b'a\r\n'
+        this_text = b'b\r\n'
+        other_text = b'c\r\n'
         m3 = merge3.Merge3(base_text.splitlines(True),
                            other_text.splitlines(True),
                            this_text.splitlines(True))
-        m_lines = m3.merge_lines('OTHER', 'THIS')
-        self.assertEqual('<<<<<<< OTHER\r\nc\r\n=======\r\nb\r\n'
-            '>>>>>>> THIS\r\n'.splitlines(True), list(m_lines))
+        m_lines = m3.merge_lines(b'OTHER', b'THIS')
+        self.assertEqual(b'<<<<<<< OTHER\r\nc\r\n=======\r\nb\r\n'
+            b'>>>>>>> THIS\r\n'.splitlines(True), list(m_lines))
 
     def test_mac_text(self):
-        base_text = 'a\r'
-        this_text = 'b\r'
-        other_text = 'c\r'
+        base_text = b'a\r'
+        this_text = b'b\r'
+        other_text = b'c\r'
         m3 = merge3.Merge3(base_text.splitlines(True),
                            other_text.splitlines(True),
                            this_text.splitlines(True))
-        m_lines = m3.merge_lines('OTHER', 'THIS')
-        self.assertEqual('<<<<<<< OTHER\rc\r=======\rb\r'
-            '>>>>>>> THIS\r'.splitlines(True), list(m_lines))
+        m_lines = m3.merge_lines(b'OTHER', b'THIS')
+        self.assertEqual(b'<<<<<<< OTHER\rc\r=======\rb\r'
+            b'>>>>>>> THIS\r'.splitlines(True), list(m_lines))
 
     def test_merge3_cherrypick(self):
-        base_text = "a\nb\n"
-        this_text = "a\n"
-        other_text = "a\nb\nc\n"
+        base_text = b"a\nb\n"
+        this_text = b"a\n"
+        other_text = b"a\nb\nc\n"
         # When cherrypicking, lines in base are not part of the conflict
         m3 = merge3.Merge3(base_text.splitlines(True),
                            this_text.splitlines(True),
                            other_text.splitlines(True), is_cherrypick=True)
         m_lines = m3.merge_lines()
-        self.assertEqualDiff('a\n<<<<<<<\n=======\nc\n>>>>>>>\n',
-                             ''.join(m_lines))
+        self.assertEqualDiff(b'a\n<<<<<<<\n=======\nc\n>>>>>>>\n',
+                             b''.join(m_lines))
 
         # This is not symmetric
         m3 = merge3.Merge3(base_text.splitlines(True),
                            other_text.splitlines(True),
                            this_text.splitlines(True), is_cherrypick=True)
         m_lines = m3.merge_lines()
-        self.assertEqualDiff('a\n<<<<<<<\nb\nc\n=======\n>>>>>>>\n',
-                             ''.join(m_lines))
+        self.assertEqualDiff(b'a\n<<<<<<<\nb\nc\n=======\n>>>>>>>\n',
+                             b''.join(m_lines))
 
     def test_merge3_cherrypick_w_mixed(self):
-        base_text = 'a\nb\nc\nd\ne\n'
-        this_text = 'a\nb\nq\n'
-        other_text = 'a\nb\nc\nd\nf\ne\ng\n'
+        base_text = b'a\nb\nc\nd\ne\n'
+        this_text = b'a\nb\nq\n'
+        other_text = b'a\nb\nc\nd\nf\ne\ng\n'
         # When cherrypicking, lines in base are not part of the conflict
         m3 = merge3.Merge3(base_text.splitlines(True),
                            this_text.splitlines(True),
                            other_text.splitlines(True), is_cherrypick=True)
         m_lines = m3.merge_lines()
-        self.assertEqualDiff('a\n'
-                             'b\n'
-                             '<<<<<<<\n'
-                             'q\n'
-                             '=======\n'
-                             'f\n'
-                             '>>>>>>>\n'
-                             '<<<<<<<\n'
-                             '=======\n'
-                             'g\n'
-                             '>>>>>>>\n',
-                             ''.join(m_lines))
+        self.assertEqualDiff(b'a\n'
+                             b'b\n'
+                             b'<<<<<<<\n'
+                             b'q\n'
+                             b'=======\n'
+                             b'f\n'
+                             b'>>>>>>>\n'
+                             b'<<<<<<<\n'
+                             b'=======\n'
+                             b'g\n'
+                             b'>>>>>>>\n',
+                             b''.join(m_lines))
 
     def test_allow_objects(self):
         """Objects other than strs may be used with Merge3 when

=== modified file 'breezy/tests/test_merge_core.py'
--- breezy/tests/test_merge_core.py	2018-06-29 17:57:21 +0000
+++ breezy/tests/test_merge_core.py	2018-07-08 14:45:27 +0000
@@ -261,12 +261,12 @@
         builder = MergeBuilder(getcwd())
         builder.add_dir(b"1", builder.tree_root, "dir1")
         builder.add_dir(b"2", builder.tree_root, "dir2")
-        builder.add_file(b"3", "1", "file1", b"hello1", True)
-        builder.add_file(b"4", "1", "file2", b"hello2", True)
-        builder.add_file(b"5", "1", "file3", b"hello3", True)
-        builder.change_parent(b"3", other="2")
-        builder.change_parent(b"4", this="2")
-        builder.change_parent(b"5", base="2")
+        builder.add_file(b"3", b"1", "file1", b"hello1", True)
+        builder.add_file(b"4", b"1", "file2", b"hello2", True)
+        builder.add_file(b"5", b"1", "file3", b"hello3", True)
+        builder.change_parent(b"3", other=b"2")
+        builder.change_parent(b"4", this=b"2")
+        builder.change_parent(b"5", base=b"2")
         builder.merge()
         builder.cleanup()
 
@@ -274,8 +274,8 @@
         builder.add_dir(b"1", builder.tree_root, "dir1")
         builder.add_dir(b"2", builder.tree_root, "dir2")
         builder.add_dir(b"3", builder.tree_root, "dir3")
-        builder.add_file(b"4", "1", "file1", b"hello1", False)
-        builder.change_parent(b"4", other="2", this="3")
+        builder.add_file(b"4", b"1", "file1", b"hello1", False)
+        builder.change_parent(b"4", other=b"2", this=b"3")
         conflicts = builder.merge()
         path2 = pathjoin('dir2', 'file1')
         path3 = pathjoin('dir3', 'file1')
@@ -361,9 +361,9 @@
     def contents_test_conflicts(self, merge_factory):
         builder = MergeBuilder(getcwd())
         builder.add_file(b"1", builder.tree_root, "name1", b"text1", True)
-        builder.change_contents("1", other=b"text4", this=b"text3")
+        builder.change_contents(b"1", other=b"text4", this=b"text3")
         builder.add_file(b"2", builder.tree_root, "name2", b"text1", True)
-        builder.change_contents("2", other=b"\x00", this="text3")
+        builder.change_contents(b"2", other=b"\x00", this=b"text3")
         builder.add_file(b"3", builder.tree_root, "name3", b"text5", False)
         builder.change_perms(b"3", this=True)
         builder.change_contents(b'3', this=b'moretext')
@@ -372,9 +372,8 @@
         self.assertEqual(conflicts, [TextConflict('name1', file_id=b'1'),
                                      ContentsConflict('name2', file_id=b'2'),
                                      ContentsConflict('name3', file_id=b'3')])
-        self.assertEqual(
-            builder.this.get_file(builder.this.id2path(b'2')).read(),
-            '\x00')
+        with builder.this.get_file(builder.this.id2path(b'2')) as f:
+            self.assertEqual(f.read(), b'\x00')
         builder.cleanup()
 
     def test_symlink_conflicts(self):
@@ -393,9 +392,9 @@
             builder.add_symlink(b"1", builder.tree_root, "name1", "target1")
             builder.add_symlink(b"2", builder.tree_root, "name2", "target1")
             builder.add_symlink(b"3", builder.tree_root, "name3", "target1")
-            builder.change_target(b"1", this="target2")
-            builder.change_target(b"2", base="target2")
-            builder.change_target(b"3", other="target2")
+            builder.change_target(b"1", this=b"target2")
+            builder.change_target(b"2", base=b"target2")
+            builder.change_target(b"3", other=b"target2")
             builder.merge()
             self.assertEqual(builder.this.get_symlink_target("name1"), "target2")
             self.assertEqual(builder.this.get_symlink_target("name2"), "target1")
@@ -469,23 +468,23 @@
         self.build_tree(("mary/",))
         branch.controldir.clone("mary")
         # Now John commits a change
-        file = open("original/file1", "wt")
-        file.write("John\n")
-        file.close()
+        with open("original/file1", "wt") as f:
+            f.write("John\n")
         tree.commit("change file1")
         # Mary does too
         mary_tree = WorkingTree.open('mary')
         mary_branch = mary_tree.branch
-        file = open("mary/file2", "wt")
-        file.write("Mary\n")
-        file.close()
+        with open("mary/file2", "wt") as f:
+            f.write("Mary\n")
         mary_tree.commit("change file2")
         # john should be able to merge with no conflicts.
         base = [None, None]
         other = ("mary", -1)
         tree.merge_from_branch(mary_tree.branch)
-        self.assertEqual("John\n", open("original/file1", "rt").read())
-        self.assertEqual("Mary\n", open("original/file2", "rt").read())
+        with open("original/file1", "rt") as f:
+            self.assertEqual("John\n", f.read())
+        with open("original/file2", "rt") as f:
+            self.assertEqual("Mary\n", f.read())
 
     def test_conflicts(self):
         wta = self.make_branch_and_tree('a')

=== modified file 'breezy/tests/test_merge_directive.py'
--- breezy/tests/test_merge_directive.py	2018-06-29 15:36:29 +0000
+++ breezy/tests/test_merge_directive.py	2018-07-08 14:45:27 +0000
@@ -157,16 +157,16 @@
         time = 500000.0
         timezone = 5 * 3600
         self.assertRaises(errors.NoMergeSource, self.make_merge_directive,
-            'example:', 'sha', time, timezone, 'http://example.com')
+            'example:', b'sha', time, timezone, 'http://example.com')
         self.assertRaises(errors.NoMergeSource, self.make_merge_directive,
-            'example:', 'sha', time, timezone, 'http://example.com',
+            'example:', b'sha', time, timezone, 'http://example.com',
             patch_type='diff')
-        self.make_merge_directive('example:', 'sha', time, timezone,
+        self.make_merge_directive('example:', b'sha', time, timezone,
             'http://example.com', source_branch='http://example.org')
-        md = self.make_merge_directive('null:', 'sha', time, timezone,
+        md = self.make_merge_directive('null:', b'sha', time, timezone,
             'http://example.com', patch='blah', patch_type='bundle')
         self.assertIs(None, md.source_branch)
-        md2 = self.make_merge_directive('null:', 'sha', time, timezone,
+        md2 = self.make_merge_directive('null:', b'sha', time, timezone,
             'http://example.com', patch='blah', patch_type='bundle',
             source_branch='bar')
         self.assertEqual('bar', md2.source_branch)
@@ -174,10 +174,10 @@
     def test_serialization(self):
         time = 453
         timezone = 120
-        md = self.make_merge_directive('example:', 'sha', time, timezone,
+        md = self.make_merge_directive('example:', b'sha', time, timezone,
             'http://example.com', patch='booga', patch_type='bundle')
         self.assertEqualDiff(self.OUTPUT1, b''.join(md.to_lines()))
-        md = self.make_merge_directive('example:', 'sha', time, timezone,
+        md = self.make_merge_directive('example:', b'sha', time, timezone,
             'http://example.com', source_branch="http://example.org",
             patch='booga', patch_type='diff', message="Hi mom!")
         self.assertEqualDiff(self.OUTPUT2, b''.join(md.to_lines()))
@@ -193,20 +193,20 @@
 
     def test_deserialize_leading_junk(self):
         md = merge_directive.MergeDirective.from_lines(self.INPUT1)
-        self.assertEqual('example:', md.revision_id)
+        self.assertEqual(b'example:', md.revision_id)
         self.assertEqual('sha', md.testament_sha1)
         self.assertEqual('http://example.com', md.target_branch)
         self.assertEqual('http://example.org', md.source_branch)
         self.assertEqual(453, md.time)
         self.assertEqual(120, md.timezone)
-        self.assertEqual('booga', md.patch)
+        self.assertEqual(b'booga', md.patch)
         self.assertEqual('diff', md.patch_type)
         self.assertEqual('Hi mom!', md.message)
 
     def test_roundtrip(self):
         time = 500000
         timezone = 7.5 * 3600
-        md = self.make_merge_directive('example:', 'sha', time, timezone,
+        md = self.make_merge_directive('example:', b'sha', time, timezone,
             'http://example.com', source_branch="http://example.org",
             patch='booga', patch_type='diff')
         md2 = merge_directive.MergeDirective.from_lines(md.to_lines())
@@ -259,9 +259,9 @@
         time = 500.0
         timezone = 120
         self.assertRaises(errors.PatchMissing, merge_directive.MergeDirective,
-            'example:', 'sha', time, timezone, 'http://example.com',
+            'example:', b'sha', time, timezone, 'http://example.com',
             patch_type='bundle')
-        md = merge_directive.MergeDirective('example:', 'sha1', time, timezone,
+        md = merge_directive.MergeDirective('example:', b'sha1', time, timezone,
             'http://example.com', source_branch="http://example.org",
             patch='', patch_type='diff')
         self.assertEqual(md.patch, '')
@@ -454,7 +454,7 @@
         md1 = self.from_objects(tree_a.branch.repository, b'rev2a', 500, 120,
             tree_b.branch.base, public_branch=branch_c.base)
         lines = md1.to_lines()
-        lines = [l.replace('\n', '\r\n') for l in lines]
+        lines = [l.replace(b'\n', b'\r\n') for l in lines]
         md2 = merge_directive.MergeDirective.from_lines(lines)
         self.assertEqual(b'rev2a', md2.revision_id)
 
@@ -464,7 +464,7 @@
         class FakeBranch(object):
             def get_config_stack(self):
                 return self
-        md = self.make_merge_directive('example:', 'sha', time, timezone,
+        md = self.make_merge_directive('example:', b'sha', time, timezone,
             'http://example.com', source_branch="http://example.org",
             patch='booga', patch_type='diff')
         old_strategy = gpg.GPGStrategy
@@ -694,7 +694,7 @@
         self.assertEqual('http://example.org', md.source_branch)
         self.assertEqual(453, md.time)
         self.assertEqual(120, md.timezone)
-        self.assertEqual('booga', md.patch)
+        self.assertEqual(b'booga', md.patch)
         self.assertEqual('diff', md.patch_type)
         self.assertEqual('Hi mom!', md.message)
 
@@ -734,7 +734,7 @@
         tree = self.make_branch_and_tree('foo')
         tree.commit('foo')
         directive = merge_directive.MergeDirective2(
-            tree.branch.last_revision(), 'sha', 0, 0, 'sha',
+            tree.branch.last_revision(), b'sha', 0, 0, b'sha',
             source_branch=tree.branch.base,
             base_revision_id=tree.branch.last_revision(),
             message='This code rox')

=== modified file 'python3.passing'
--- python3.passing	2018-07-04 12:50:55 +0000
+++ python3.passing	2018-07-08 14:45:27 +0000
@@ -1438,7 +1438,9 @@
 breezy.tests.blackbox.test_ls.TestLS.test_ls_ignored
 breezy.tests.blackbox.test_ls.TestLS.test_ls_no_recursive
 breezy.tests.blackbox.test_ls.TestLS.test_ls_revision
+breezy.tests.blackbox.test_merge_directive.TestMergeDirective.test_mail_uses_config
 breezy.tests.blackbox.test_merge_directive.TestMergeDirective.test_merge_raw
+breezy.tests.blackbox.test_merge_directive.TestMergeDirective.test_no_common_ancestor
 breezy.tests.blackbox.test_merge_directive.TestMergeDirective.test_pull_raw
 breezy.tests.blackbox.test_merge.TestMergeForce.test_merge_force
 breezy.tests.blackbox.test_merge.TestMergeRevisionRange.test_merge_reversed_revision_range(file-only)
@@ -21935,8 +21937,28 @@
 breezy.tests.test_memorytree.TestMemoryTree.test_put_new_file
 breezy.tests.test_memorytree.TestMemoryTree.test_unversion
 breezy.tests.test_merge3.TestMerge3.test_allow_objects
+breezy.tests.test_merge3.TestMerge3.test_append_a
+breezy.tests.test_merge3.TestMerge3.test_append_agreement
+breezy.tests.test_merge3.TestMerge3.test_append_b
+breezy.tests.test_merge3.TestMerge3.test_append_clash
+breezy.tests.test_merge3.TestMerge3.test_binary
+breezy.tests.test_merge3.TestMerge3.test_dos_text
+breezy.tests.test_merge3.TestMerge3.test_front_insert
+breezy.tests.test_merge3.TestMerge3.test_insert_agreement
+breezy.tests.test_merge3.TestMerge3.test_insert_clash
+breezy.tests.test_merge3.TestMerge3.test_mac_text
+breezy.tests.test_merge3.TestMerge3.test_merge3_cherrypick
+breezy.tests.test_merge3.TestMerge3.test_merge3_cherrypick_w_mixed
+breezy.tests.test_merge3.TestMerge3.test_merge_poem
+breezy.tests.test_merge3.TestMerge3.test_minimal_conflicts_common
+breezy.tests.test_merge3.TestMerge3.test_minimal_conflicts_nonunique
+breezy.tests.test_merge3.TestMerge3.test_minimal_conflicts_unique
+breezy.tests.test_merge3.TestMerge3.test_no_changes
+breezy.tests.test_merge3.TestMerge3.test_no_conflicts
+breezy.tests.test_merge3.TestMerge3.test_null_insert
 breezy.tests.test_merge3.TestMerge3.test_replace_clash
 breezy.tests.test_merge3.TestMerge3.test_replace_multi
+breezy.tests.test_merge3.TestMerge3.test_reprocess_and_base
 breezy.tests.test_merge_core.FunctionalMergeTest.test_merge_create_before_rename
 breezy.tests.test_merge_core.FunctionalMergeTest.test_merge_delete_and_add_same
 breezy.tests.test_merge_core.FunctionalMergeTest.test_merge_delete_before_rename_to_temp
@@ -21949,6 +21971,9 @@
 breezy.tests.test_merge_core.FunctionalMergeTest.test_merge_unrelated_conflicting
 breezy.tests.test_merge_core.FunctionalMergeTest.test_trivial_star_merge
 breezy.tests.test_merge_core.MergeTest.test_change_name
+breezy.tests.test_merge_core.MergeTest.test_contents_merge
+breezy.tests.test_merge_core.MergeTest.test_contents_merge2
+breezy.tests.test_merge_core.MergeTest.test_file_moves
 breezy.tests.test_merge_core.MergeTest.test_merge_one
 breezy.tests.test_merge_core.MergeTest.test_merge_one_renamed
 breezy.tests.test_merge_core.MergeTest.test_new_suffix
@@ -21957,9 +21982,14 @@
 breezy.tests.test_merge_core.MergeTest.test_spurious_conflict
 breezy.tests.test_merge_core.MergeTest.test_symlink_conflicts
 breezy.tests.test_merge_core.MergeTest.test_symlink_merge
+breezy.tests.test_merge_core.TestMerger.test_from_mergeable
 breezy.tests.test_merge_core.TestMerger.test_from_revision_ids
 breezy.tests.test_merge_core.TestMerger.test_from_uncommitted
+breezy.tests.test_merge_directive.TestBodyHook.test_body_hook
+breezy.tests.test_merge_directive.TestBodyHook.test_body_hook_chaining
+breezy.tests.test_merge_directive.TestBodyHook.test_no_supports_body
 breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_disk_name_old_revno
+breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_email
 breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_get_target_revision_nofetch
 breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_handle_target_not_a_branch
 breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_install_revisions_branch
@@ -21968,14 +21998,18 @@
 breezy.tests.test_merge_directive.TestMergeDirective1Branch.test_use_submit_for_missing_dependency
 breezy.tests.test_merge_directive.TestMergeDirective1.test_deserialize_empty
 breezy.tests.test_merge_directive.TestMergeDirective1.test_deserialize_junk
+breezy.tests.test_merge_directive.TestMergeDirective1.test_deserialize_leading_junk
 breezy.tests.test_merge_directive.TestMergeDirective1.test_merge_source
 breezy.tests.test_merge_directive.TestMergeDirective1.test_require_patch
+breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_disk_name_old_revno
+breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_email
 breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_get_target_revision_nofetch
 breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_install_revisions_branch
 breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_message
 breezy.tests.test_merge_directive.TestMergeDirective2Branch.test_use_public_submit_branch
 breezy.tests.test_merge_directive.TestMergeDirective2.test_deserialize_empty
 breezy.tests.test_merge_directive.TestMergeDirective2.test_deserialize_junk
+breezy.tests.test_merge_directive.TestMergeDirective2.test_deserialize_leading_junk
 breezy.tests.test_merge_directive.TestMergeDirective2.test_merge_source
 breezy.tests.test_merge.TestConfigurableFileMerger.test_affected_files_cached
 breezy.tests.test_merge.TestConfigurableFileMerger.test_hook_called_for_text_conflicts
@@ -21991,23 +22025,33 @@
 breezy.tests.test_merge.TestLCAMultiWay.test_this_in_lca
 breezy.tests.test_merge.TestMergeHooks.test_post_merge_hook_called
 breezy.tests.test_merge.TestMergeHooks.test_pre_merge_hook_inject_different_tree
+breezy.tests.test_merge.TestMergeInto.test_no_such_source_path
+breezy.tests.test_merge.TestMergeInto.test_no_such_target_path
+breezy.tests.test_merge.TestMergeInto.test_only_file
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_all_wt
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_both_sides_revert
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_conflict_without_lca
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_create_symlink
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_executable_changes
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_modified_symlink
+breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_nested_tree_subtree_modified
+breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_nested_tree_subtree_renamed
+breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_nested_tree_unmodified
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_other_deletes_lca_renames
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_other_modified_content
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_other_reverted_content_to_base
+breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_other_reverted_path_to_base
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_renamed_symlink
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_simple_lca
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_symlink_all_wt
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_symlink_no_content_change
 breezy.tests.test_merge.TestMergerEntriesLCAOnDisk.test_symlink_this_changed_kind
+breezy.tests.test_merge.TestMergerEntriesLCA.test_both_sides_revert
+breezy.tests.test_merge.TestMergerEntriesLCA.test_different_lca_resolve_one_side_updates_content
 breezy.tests.test_merge.TestMergerEntriesLCA.test_file_not_in_one_lca
 breezy.tests.test_merge.TestMergerEntriesLCA.test_interesting_file_in_base
 breezy.tests.test_merge.TestMergerEntriesLCA.test_interesting_file_in_lca
+breezy.tests.test_merge.TestMergerEntriesLCA.test_interesting_file_in_this
 breezy.tests.test_merge.TestMergerEntriesLCA.test_interesting_files
 breezy.tests.test_merge.TestMergerEntriesLCA.test_kind_changed
 breezy.tests.test_merge.TestMergerEntriesLCA.test_not_in_base
@@ -22019,6 +22063,7 @@
 breezy.tests.test_merge.TestMergerEntriesLCA.test_only_in_one_lca
 breezy.tests.test_merge.TestMergerEntriesLCA.test_only_in_other
 breezy.tests.test_merge.TestMergerEntriesLCA.test_only_path_changed
+breezy.tests.test_merge.TestMergerEntriesLCA.test_simple
 breezy.tests.test_merge.TestMergerEntriesLCA.test_this_changed_kind
 breezy.tests.test_merge.TestMergerInMemory.test_cache_trees_with_revision_ids_having_revision_id
 breezy.tests.test_merge.TestMergerInMemory.test_cache_trees_with_revision_ids_None
@@ -22035,6 +22080,10 @@
 breezy.tests.test_merge.TestMerge.test_do_merge
 breezy.tests.test_merge.TestMerge.test_ignore_zero_merge_inner
 breezy.tests.test_merge.TestMerge.test_layered_rename
+breezy.tests.test_merge.TestMerge.test_make_merger
+breezy.tests.test_merge.TestMerge.test_make_preview_transform
+breezy.tests.test_merge.TestMerge.test_merge3_can_reverse_cherrypick
+breezy.tests.test_merge.TestMerge.test_merge3_will_detect_cherrypick
 breezy.tests.test_merge.TestMerge.test_merge_add_into_deleted_root
 breezy.tests.test_merge.TestMerge.test_merge_inner_conflicts
 breezy.tests.test_merge.TestMerge.test_merge_into_null_tree
@@ -22055,9 +22104,13 @@
 breezy.tests.test_merge.TestMerge.test_two_roots
 breezy.tests.test_merge.TestMerge.test_undo
 breezy.tests.test_merge.TestMerge.test_unrelated
+breezy.tests.test_merge.TestMerge.test_weave_cannot_reverse_cherrypick
+breezy.tests.test_merge.TestPlanMerge.test_plan_merge_cherrypick
+breezy.tests.test_merge.TestPlanMerge.test_plan_merge_no_common_ancestor
 breezy.tests.test_merge.TestPlanMerge.test__prune_tails
 breezy.tests.test_merge.TestPlanMerge.test__remove_external_references
 breezy.tests.test_merge.TestPlanMerge.test_subtract_plans
+breezy.tests.test_merge.TestPlanMerge.test_unique_lines
 breezy.tests.test_mergetools.TestCheckAvailability.test_exe_on_path
 breezy.tests.test_mergetools.TestCheckAvailability.test_full_path
 breezy.tests.test_mergetools.TestCheckAvailability.test_non_executable

